package org.example.controller;

import jakarta.servlet.ServletException;
import jakarta.servlet.annotation.WebServlet;
import jakarta.servlet.http.HttpServlet;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import jakarta.servlet.http.HttpSession;
import org.example.model.InvalidNewsException;
import org.example.model.NewsAgency;
import org.example.model.NewsItem;

import java.io.IOException;
import java.util.List;

@WebServlet("/news")
public class NewsServlet extends HttpServlet {

	private static final String ADMIN_USERNAME = "admin";

	private final NewsAgency newsAgency = NewsAgency.getInstance();

	@Override
	public void doGet(HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException {
		String keyword = request.getParameter("keyword");
		request.getSession().setAttribute("keyword", keyword);
		List<NewsItem> news = keyword == null ? newsAgency.getNews() : newsAgency.searchNews(keyword);
		request.setAttribute("news", news);
		request.getRequestDispatcher("news.jsp").forward(request, response);
	}

	@Override
	public void doPost(HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException {
		String username = (String) request.getSession().getAttribute("username");
		if (username == null || !username.equals(ADMIN_USERNAME)) {
			response.sendRedirect("login.jsp");
			return;
		}
		String text = request.getParameter("text");
		try {
			newsAgency.postNews(text);
			request.setAttribute("message", "News successfully posted");
		} catch (InvalidNewsException ex) {
			request.setAttribute("message", "News contains invalid characters");
		}
		request.getRequestDispatcher("desk.jsp").forward(request, response);
	}
}
